import React, { Component } from 'react';
import Uuid from 'uuid';
import classnames from 'classnames';
import PropTypes from 'prop-types';
import './alert.less';
import Icon from './../icon/icon';
import ProgressSpinner from './../progress-spinner/progress-spinner';

export default function Alert({
    alertType,
    id,
    message,
    showIcon,
    subClass,
    width
}) {
    const className = classnames(
        'tsdev-alert', alertType, subClass
    );
    const inlineStyle = {
        width: width
    };
    const inlineStyleDefaultIcon = {
        display: alertType !== 'spinner' ? 'inline-block' : 'none'
    };
    const inlineStyleSpinner = {
        display: alertType === 'spinner' ? 'inline-block' : 'none'
    };
    const inlineStyleIconWrapper = {
        display: showIcon ? 'inline-block' : 'none'
    };

    return (
        <div id={id}
            className={className}
            style={inlineStyle}>
            <div className="alert-icon-wrapper"
                style={inlineStyleIconWrapper}>
                <div className="alert-icon"
                    style={inlineStyleDefaultIcon}>
                    <Icon size={20}
                        iconType={alertType} />
                </div>
                <div className="alert-icon"
                    style={inlineStyleSpinner}>
                    <ProgressSpinner size="sm" />
                </div>
            </div>
            <div className="alert-text">
                {message}
            </div>
        </div>
    );
}

Alert.propTypes = {
    alertType: PropTypes.string,
    id: PropTypes.string,
    message: PropTypes.string,
    showIcon: PropTypes.bool,
    subClass: PropTypes.string,
    width: PropTypes.oneOfType([
        PropTypes.string,
        PropTypes.number
    ])
};

Alert.defaultProps = {
    alertType: 'info',
    id: `tsdevAlert-${Uuid.v4()}`,
    message: 'Alert Message',
    showIcon: true,
    subClass: '',
    width: 500
};

Alert.displayName = 'Alert';
