import React, { Component } from 'react';
import Uuid from 'uuid';
import classnames from 'classnames';
import PropTypes from 'prop-types';
import noop from 'lodash/noop';
import './outlined-button.less';
import Button from '@material-ui/core/Button';

export default class OutlinedButton extends Component {
    constructor(props) {
        super(props);
        this.state = {
            pressed: false,
            hovered: false
        };
        this.handleOnClick = this.handleOnClick.bind(this);
        this.handleOnMouseDown = this.handleOnMouseDown.bind(this);
        this.handleOnHover = this.handleOnHover.bind(this);
        this.handleOnMouseUp = this.handleOnMouseUp.bind(this);
    }

    handleOnClick(event) {
        const {
            onClick
        } = this.props;

        event.stopPropagation();
        event.preventDefault();

        onClick(this.props);
    }

    handleOnMouseDown() {
        this.setState({
            pressed: true,
            hovered: false
        });
    }

    handleOnMouseUp() {
        this.setState({
            pressed: false
        });
    }

    handleOnHover() {
        const {
            pressed,
            hovered
        } = this.state;

        this.setState({
            hovered: !hovered && !pressed
        });
    }

    render() {
        const {
            pressed,
            hovered
        } = this.state;
        const {
            id,
            label,
            subClass,
            inactive,
            buttonType
        } = this.props;
        const className = classnames(
            'tsdev-button',
            'tsdev-outlined-button',
            buttonType,
            subClass,
            { inactive: inactive },
            { pressed: pressed },
            { hovered: hovered }
        );
        const muiClassName = classnames(
            { pressed: pressed },
            { inactive: inactive },
            'MuiButton-outlined-' + buttonType
        );

        return (
            <div id={id}
                className={className}
                onMouseEnter={this.handleOnHover}
                onMouseLeave={this.handleOnHover}
                onMouseDown={this.handleOnMouseDown}
                onMouseUp={this.handleOnMouseUp}
                onClick={this.handleOnClick}>
                <Button variant="outlined"
                    disabled={inactive}
                    className={muiClassName}>
                    {label}
                </Button>
            </div>
        );
    }
}

OutlinedButton.propTypes = {
    buttonType: PropTypes.string,
    id: PropTypes.string,
    inactive: PropTypes.bool,
    label: PropTypes.string,
    onClick: PropTypes.func,
    subClass: PropTypes.string
};

OutlinedButton.defaultProps = {
    buttonType: 'primary',
    id: `tsdevButtonOutlined-${Uuid.v4()}`,
    inactive: false,
    label: 'Outlined',
    onClick: noop,
    subClass: ''
};

OutlinedButton.displayName = 'OutlinedButton';
